PumaFirebase class
Constructors
- PumaFirebase({required dynamic onInitSuccess(PumaFirebase), required dynamic onInitError(Object), dynamic onUserSignIn(User)?, FirebaseOptions? options, dynamic onTokenReceived(String?)?, dynamic onUserSignOut()?, bool pushNotifications = false, bool authentication = false, bool analytics = false, void onMessage(PumaFireMessage)?, void onMessageOpenedApp(PumaFireMessage)?})
Properties
- analytics → bool
-
final
- authentication → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- onInitError → dynamic Function(Object)
-
final
- onInitSuccess → dynamic Function(PumaFirebase)
-
final
- onMessage → void Function(PumaFireMessage)?
-
final
- onMessageOpenedApp → void Function(PumaFireMessage)?
-
final
- onTokenReceived → dynamic Function(String?)?
-
final
- onUserSignIn → dynamic Function(User)?
-
final
- onUserSignOut → dynamic Function()?
-
final
- options → FirebaseOptions?
-
final
- pushNotifications → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
analyticsInit(
) → void -
appInit(
FirebaseOptions? options) → void -
authInit(
) → void -
messagingInit(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
deleteAccount(
{required String provider, required dynamic onCompleted(bool, PumaFireUser), required dynamic onError(dynamic)}) → dynamic -
getUser(
) → PumaFireUser -
isNotificationGranted(
{required void onGranted(), required void onFailed()}) → dynamic -
isSignedIn(
) → bool -
signInWithApple(
{required dynamic onCompleted(bool, PumaFireUser), required dynamic onError(dynamic)}) → void -
signInWithGoogle(
{required dynamic onCompleted(bool, PumaFireUser), required dynamic onError(dynamic)}) → void -
signOut(
) → dynamic -
subscribeToNotification(
String topic) → void -
unsubscribeFromNotification(
String topic) → void